/*
 * Copyright (C) 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.server.uwb.secure.csml;

import static com.google.common.truth.Truth.assertThat;

import com.android.server.uwb.util.DataTypeConversionUtil;
import com.android.server.uwb.util.ObjectIdentifier;

import org.junit.Test;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class InitiateTransactionCommandTest {
    @Test
    public void encodeUnicastInitiateTransactionCommand() {
        List<ObjectIdentifier> adfOids = Arrays.asList(
                ObjectIdentifier.fromBytes(new byte[] {(byte) 0x01, (byte) 0x02}),
                ObjectIdentifier.fromBytes(new byte[] {(byte) 0x01, (byte) 0x03}));
        // <code>cla | ins | p1 | p2 | lc | data | le</code>
        byte[] expectedApdu = DataTypeConversionUtil.hexStringToByteArray(
                "8012000008060201020602010300");
        byte[] actualApdu = InitiateTransactionCommand.buildForUnicast(adfOids)
                .getCommandApdu().getEncoded();

        assertThat(actualApdu).isEqualTo(expectedApdu);
    }

    @Test
    public void encodeMulticastInitiateTransactionCommand() {
        List<ObjectIdentifier> adfOids = Arrays.asList(
                ObjectIdentifier.fromBytes(new byte[] {(byte) 0x01, (byte) 0x02}),
                ObjectIdentifier.fromBytes(new byte[] {(byte) 0x01, (byte) 0x03}));
        int sessionId = 0x0A0B0C0D;
        // <code>cla | ins | p1 | p2 | lc | data | le</code>
        byte[] expectedApdu = DataTypeConversionUtil.hexStringToByteArray(
                "801201000E80040A0B0C0D060201020602010300");
        byte[] actualApdu = InitiateTransactionCommand.buildForMulticast(adfOids, sessionId)
                .getCommandApdu().getEncoded();

        assertThat(actualApdu).isEqualTo(expectedApdu);

    }

    @Test(expected = IllegalArgumentException.class)
    public void setZeroAdfOids() {
        InitiateTransactionCommand.buildForUnicast(new ArrayList<>());
    }
}
